# Interleave Playlist
![Tests](https://github.com/tsweeney256/interleave_playlist/actions/workflows/tests.yml/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/tsweeney256/interleave_playlist/badge.svg)](https://coveralls.io/github/tsweeney256/interleave_playlist)

Interleave episodes of the shows you watch to maximize variety when catching up
